#############
Aldryn-Events
#############

|PyPI Version| |Build Status| |Coverage Status| |codeclimate| |requires_io|

|Browser Matrix|

Aldryn Events is an Aldryn-compatible application for publishing information
about events in django CMS.

Please see the official `Aldryn Events documentation <http://aldryn-events.readthedocs.org>`_,
which includes information on installation and getting started.

It also contains `documentation for content editors and end-users
<http://aldryn-events.readthedocs.org/en/latest/user/index.html>`_.


************
Contributing
************

Aldryn Events is a an open-source project. We'll be delighted to receive your
feedback in the form of issues and pull requests. Before submitting your pull
request, please review our `guidelines for Aldryn addons <http://docs.aldryn.com/en/latest/reference/addons/index.html>`_.


************
Requirements
************

* Python 2.6 or 2.7
* django CMS 3.0.12 or later
* Django 1.6 or 1.7


Optional requirements
=====================

* django-tablib

Package should be installed manually. Also take in account ``django-tablib``
limitations which are listed below.

Python 2.6
----------

If you are planning to use ``aldryn-events`` with ``Python 2.6``
be aware that event registrations export functions will not work because
``django-tablib`` package has ``Python 2.6``/``Django 1.6+`` compatibility issues.

Django 1.8
----------

Unfortunately ``django-tablib`` does not supports ``Django 1.8`` which means
that event registrations export functions will not work.


.. |PyPI Version| image:: http://img.shields.io/pypi/v/aldryn-events.svg
   :target: https://pypi.python.org/pypi/aldryn-events
.. |Build Status| image:: http://img.shields.io/travis/aldryn/aldryn-events/master.svg
   :target: https://travis-ci.org/aldryn/aldryn-events
.. |Coverage Status| image:: http://img.shields.io/coveralls/aldryn/aldryn-events/master.svg
   :target: https://coveralls.io/r/aldryn/aldryn-events?branch=master
.. |codeclimate| image:: https://codeclimate.com/github/aldryn/aldryn-events/badges/gpa.svg
   :target: https://codeclimate.com/github/aldryn/aldryn-events
   :alt: Code Climate
.. |requires_io| image:: https://requires.io/github/aldryn/aldryn-events/requirements.svg?branch=master
   :target: https://requires.io/github/aldryn/aldryn-events/requirements/?branch=master
   :alt: Requirements Status
.. |Browser Matrix| image:: https://saucelabs.com/browser-matrix/aldryn-events.svg
   :target: https://saucelabs.com/u/aldryn-events
